.BG
.FN hare.fit
.TL
Non-Proportional Hazards Regression.
.DN
Non-proportional hazards regression using linear splines.
.CS
hare.fit(data, delta, cov, penalty, maxdim, 
         exclude, include, prophaz=F, additive=F, 
         linear=F, fit, silent=T)
.RA
.AG data
vector of observations. Observations may or may not be right censored. All
observations should be non-negative.
.AG delta
binary vector with the same length as `data'. Elements of `data'
for which the corresponding element of delta is 0 are assumed to be
right censored, elements of `data'
for which the corresponding element of delta is 1 are assumed to be
uncensored. If delta is missing, all observations are assumed to be uncensored.
.OA
.AG cov
covariates: matrix with as many rows as the length of `data'. May be omitted
if there are no covariates.
.AG penalty
the parameter to be used in the AIC criterion. The method chooses
the number of knots that minimizes -2*loglikelihood+penalty*(dimension).
The default is to use `penalty=log(samplesize)' as in BIC. The effect of
this parameter is summarized in `hare.summary'.
.AG maxdim
maximum dimension (default is `6*length(data)^0.2').
.AG exclude
combinations to be excluded - this should be a matrix with 2
columns - if for example `exclude(1,1)=2' and `exclude(1,2)=3' no
interaction between covariate 2 and 3 is included. 0 represents time.
.AG include
those combinations that can be included. Should have the same format
as `exclude'. Only one of `exclude' and `include' can be specified.
.AG prophaz
should a proportional hazard model be fitted?
.AG additive
should an additive model be fitted?
.AG linear
vector indicating for which of the variables no knots should
be entered. For example, if `linear=c(2,3)' no knots for either covariate
2 or 3 are entered. 0 represents time.
.AG fit
object created by `hare.fit'. If a `fit' is specified, `hare.fit' adds
basis functions starting with those in the specified fit.
.AG silent
suppresses the printing of diagnostic output about basis functions added
or deleted, Rao-statistics, Wald-statistics and log-likelihoods.
.RT
The output is organized to serve as input for `hare.plot',
`hare.summary', `dhare', `hhare', `phare', `qhare' and `rhare'.
The function returns a list with the following members:
.RC ncov
number of covariates
.RC ndim
number of dimensions of the fitted model
.RC fcts
matrix of size `ndim x 6'. Each row is a basis function.
First element: first covariate involved (0=time);
.br
second element: which knot (0 means: constant (time) or linear (covariate));
.br
third element: second covariate involved (`NA' means: this is a function of one variable);
.br
fourth element: knot involved (if the third element is `NA', of no relevance);
.br
fifth element: beta;
.br
sixth element: standard error of beta.
.RC knots
a matrix of size ncov x ?
one row for each dimension. Covariate i has row i+1, time has row 1.
first element - number of knots in this dimension
other elements - the knots, appended with NAs to make it a matrix
.RC penalty
the parameter used in the AIC criterion.
.RC max
maximum element of `data'.
.RC ranges
column i gives the range of the i-th covariate.
.RC logl
matrix with two columns. The i-th element of the first column 
is the loglikelihood of the model of dimension i. The second column indicates whether this
model was fitted during the addition stage (1) or during the deletion stage (0).
.RC sample
sample size.
.EX
fit <- hare.fit(time, delta, covs)
.SH REFERENCE
Kooperberg, C., Stone, C. J. and Truong, Y. K. (1995),
Hazard regression.
.ul
Journal of the American Statistical Association,
\fB90\fP, 78-94.
.SA
`hare.plot', `hare.summary', `dhare', `hhare', `phare', `qhare', `rhare'.
.WR
